<?php
/*
Plugin Name: Display IDs
Version: 1.0.1
Plugin URI: http://www.wpdevelopment.in/
Description: Display hidden IDs of Posts, Pages, Categoris, Tags and many more in Admin interface
Author: Dipak Kumar Pusti
Author URI: http://iamdipak.in/
Text Domain: display-ids-for-wp-admin
Domain Path: /languages

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

/**
* The DisplayIDsForWPAdmin class
*
* @package 		WordPress_Plugins
* @subpackage 	DisplayIDsForWPAdmin
* @since 		1.0.1
*/
class DisplayIDsForWPAdmin {

	/**
 	* The DisplayIDsForWPAdmin class constructor
 	* initializing required stuff for the plugin
 	*
	* PHP 5 Constructor
 	*
 	* @since 		1.0.1
 	*/
	function __construct() {
		
		$this->textdomain_loaded = false;

		add_action('plugins_loaded', 	array(&$this, 'load_textdomain'));
		add_action('admin_init', 		array(&$this, 'init'));
		add_action('admin_head',		array(&$this, 'add_css'));
	}

	/**
 	* Initialize and load the plugin stuff
 	*
 	* @since 		1.0.1
 	* @uses 		$pagenow
 	*/
	function init() {
		
		global $wpversion, $pagenow;
		if ( !function_exists("add_action") ) return;

		add_filter('manage_media_columns', array(&$this, 'column_add'));
		add_action('manage_media_custom_column', array(&$this, 'column_value'), 10, 2);

		add_filter('manage_link-manager_columns', array(&$this, 'column_add'));
		add_action('manage_link_custom_column', array(&$this, 'column_value'), 10, 2);

		add_action('manage_edit-link-categories_columns', array(&$this, 'column_add'));
		add_filter('manage_link_categories_custom_column', array(&$this, 'column_return_value'), 10, 3);

		foreach( get_taxonomies(array('public' => true)) as $taxonomy ) {
			if( isset($taxonomy) ) {
				add_action("manage_edit-${taxonomy}_columns", array(&$this, 'column_add'));
				add_filter("manage_${taxonomy}_custom_column", array(&$this, 'column_return_value'), 10, 3);
				if( version_compare($GLOBALS['wp_version'], '3.0.999', '>') )
					add_filter("manage_edit-${taxonomy}_sortable_columns", array(&$this, 'column_add_clean') );
			}
		}

		foreach( get_post_types(array('public' => true)) as $ptype ) {
			if( isset($ptype) ) {
				add_action("manage_edit-${ptype}_columns", array(&$this, 'column_add'));
				add_filter("manage_${ptype}_posts_custom_column", array(&$this, 'column_value'), 10, 3);
				if( version_compare($GLOBALS['wp_version'], '3.0.999', '>') )
					add_filter("manage_edit-${ptype}_sortable_columns", array(&$this, 'column_add_clean') );
			}
		}

		add_action('manage_users_columns', array(&$this, 'column_add'));
		add_filter('manage_users_custom_column', array(&$this, 'column_return_value'), 10, 3);

		if( version_compare($GLOBALS['wp_version'], '3.0.999', '>') ) {
			add_action('manage_users-network_columns', array(&$this, 'column_add'));
			add_filter("manage_users_sortable_columns", array(&$this, 'column_add_clean') );
			add_filter("manage_users-network_sortable_columns", array(&$this, 'column_add_clean') );
		}

		add_action('manage_edit-comments_columns', array(&$this, 'column_add'));
		add_action('manage_comments_custom_column', array(&$this, 'column_value'), 10, 2);
		if( version_compare($GLOBALS['wp_version'], '3.0.999', '>') )
			add_filter("manage_edit-comments_sortable_columns", array(&$this, 'column_add_clean') );

		if( version_compare($GLOBALS['wp_version'], '3.0.999', '>') ) {
			add_action('manage_sites-network_columns', array(&$this, 'column_add'));
			add_filter('manage_sites_custom_column', array(&$this, 'column_value'), 10, 3);
		}
	}

	/**
	 * Adds a bit of CSS
	 *
	 * @since 1.0.1
	 */
	function add_css() {
		echo "\n";
		echo '<style type="text/css">';
		echo 'table.widefat th.column-didwpid { width: 70px; }';
		echo 'table.widefat td.column-didwpid { word-wrap: normal; }';
		echo '</style>';
		echo "\n";
	}

	/**
 	* Add the new 'ID' column
 	*
 	* @since 		1.0.1
 	*/
	function column_add( $cols ) {
		$cols['didwpid'] = '<abbr style="cursor:help;" title="' . __('Enhanced by Display IDs', 'didswpadmin') . '">' . __( 'ID', 'didswpadmin' ) . '</abbr>';
		return $cols;
	}

	/**
 	* Add the new 'ID' column without any HTMLy clutter
 	*
 	* @since 		1.0.1
 	*/
	function column_add_clean($cols) {
		$cols['didwpid'] = __( 'ID', 'didswpadmin' );
		return $cols;
	}

	/**
 	* Echo the ID for the column
 	*
 	* @since 		1.0.1
 	*/
	function column_value($column_name, $id) {
		if ($column_name == 'didwpid') echo $id;
	}

	/**
 	* Return the ID for the column
 	*
 	* @since 		1.0.1
 	*/
	function column_return_value($value, $column_name, $id) {
		if ($column_name == 'didwpid') $value = $id;
		return $value;
	}

	/**
 	* Initialize and load the plugin textdomain
 	*
 	* @since 		1.0.1
 	*/
	function load_textdomain() {
		
		if($this->textdomain_loaded) {
			return;
		}

		load_plugin_textdomain('didswpadmin', false, dirname(plugin_basename(__FILE__)) . '/languages/');
		$this->textdomain_loaded = true;
	}

}

new DisplayIDsForWPAdmin();